@@ -1,9 +1,10 @@
 ## File Name: anova_sirt.R
-## File Version: 0.18
+## File Version: 0.23
 
 ##############################################################
 # anova rasch.mml
-anova.rasch.mml <- function( object, ... ){
+anova.rasch.mml <- function( object, ... )
+{
     cl <- match.call()
     model1 <- object
     model2 <- list(object, ... )[[2]]
@@ -39,7 +40,8 @@ anova.xxirt <- anova.rasch.mml
 
 
 ##################################################################
-IRT.anova.sirt <- function (object, ...){
+IRT.anova.sirt <- function (object, ...)
+{
     cl <- match.call()
     cl2 <- paste(cl)[-1]
     if (length(list(object, ...)) !=2) {
@@ -51,12 +53,12 @@ IRT.anova.sirt <- function (object, ...){
     model1 <- IRT.IC(model1a)
     model2 <- IRT.IC(model2a)
     dfr1 <- data.frame(Model=cl2[1], loglike=model1["loglike"],
-        Deviance=-2 * model1["loglike"])
+                Deviance=-2 * model1["loglike"])
     dfr1$Npars <- model1["Npars"]
     dfr1$AIC <- model1["AIC"]
     dfr1$BIC <- model1["BIC"]
     dfr2 <- data.frame(Model=cl2[2], loglike=model2["loglike"],
-        Deviance=-2 * model2["loglike"])
+                Deviance=-2 * model2["loglike"])
     dfr2$Npars <- model2["Npars"]
     dfr2$AIC <- model2["AIC"]
     dfr2$BIC <- model2["BIC"]
@@ -67,9 +69,8 @@ IRT.anova.sirt <- function (object, ...){
     dfr$p <- NA
     dfr[1, "Chisq"] <- dfr[1, "Deviance"] - dfr[2, "Deviance"]
     dfr[1, "df"] <- abs(dfr[1, "Npars"] - dfr[2, "Npars"])
-    dfr[1, "p"] <- round(1 - stats::pchisq(dfr[1, "Chisq"], df=dfr[1,
-        "df"]), 5)
-    for (vv in 2:(ncol(dfr))) {
+    dfr[1, "p"] <- round(1 - stats::pchisq(dfr[1, "Chisq"], df=dfr[1,"df"]), 5)
+    for (vv in 2:(ncol(dfr))){
         dfr[, vv] <- round(dfr[, vv], 5)
     }
     rownames(dfr) <- NULL
@@ -77,13 +78,13 @@ IRT.anova.sirt <- function (object, ...){
     invisible(dfr)
 }
 
-
 ##############################################################
 # Likelihood ratio test for rasch.copula2 objects
-anova.rasch.copula2 <- function( object, ... ){
+anova.rasch.copula2 <- function( object, ... )
+{
     if (length(list(object, ...)) !=2){
         stop("anova method can only be applied for comparison of two models.\n")
-        }
+    }
     objects <- list(object, ...)
     model1 <- objects[[1]]
     model2 <- objects[[2]]
@@ -98,15 +99,13 @@ anova.rasch.copula2 <- function( object, ... ){
     model2$loglike <- model2$deviance / (-2)
     model2$Npars <- model2$ic$np
     # test
-    dfr1 <- data.frame( "Model"="Model 1",
-        "loglike"=model1$loglike,
-        "Deviance"=-2*model1$loglike )
+    dfr1 <- data.frame( Model='Model 1', loglike=model1$loglike,
+                Deviance=-2*model1$loglike )
     dfr1$Npars <- sum(model1$Npars)
     dfr1$AIC <- model1$AIC
     dfr1$BIC <- model1$BIC
-    dfr2 <- data.frame( "Model"="Model 2",
-        "loglike"=model2$loglike,
-        "Deviance"=-2*model2$loglike )
+    dfr2 <- data.frame( Model='Model 2', loglike=model2$loglike,
+                Deviance=-2*model2$loglike )
     dfr2$Npars <- sum(model2$Npars)
     dfr2$AIC <- model2$AIC
     dfr2$BIC <- model2$BIC
@@ -117,11 +116,11 @@ anova.rasch.copula2 <- function( object, ... ){
     dfr$p <- NA
     dfr[1,"Chisq"] <- dfr[1,"Deviance"] - dfr[2,"Deviance"]
     dfr[1,"df"] <- abs( dfr[1,"Npars"] - dfr[2,"Npars"] )
-    dfr[ 1, "p" ] <- round( 1 - stats::pchisq( dfr[1,"Chisq"], df=dfr[1,"df"] ), 5 )
+    dfr[1, "p" ] <- round( 1 - stats::pchisq( dfr[1,"Chisq"], df=dfr[1,"df"] ), 5 )
     for ( vv in 2:( ncol(dfr))){
         dfr[,vv] <- round( dfr[,vv], 5 )
     }
-    print( dfr )
+    print(dfr)
     invisible(dfr)
 }
 anova.rasch.copula3 <- anova.rasch.copula2
