@@ -1,5 +1,5 @@
 ## File Name: mcmc_summary.R
-## File Version: 0.19
+## File Version: 0.21
 
 
 ########################################################
@@ -35,7 +35,7 @@ mcmc_summary <- function( mcmcobj, quantiles=c(.025,.05,.50,.95,.975) )
     smc2 <- summary.mcmcobj$statistics
     colnames(summary.mcmcobj$quantiles) <- paste0( "Q", 100*quantiles )
     # calculate effective sample size
-    effSize <- coda::effectiveSize( mcmcobj )
+    effSize <- sirt_import_coda_effectiveSize( mcmcobj )
     statis <- summary.mcmcobj$statistics
     statis <- cbind( statis[, c(1,2) ],
                 apply( as.matrix(mcmcobj), 2, stats::mad ),
